@@ -13,12 +13,13 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
-from cysecuretools import cli
+from cysecuretools.cli_creator import CliCreator
 
 
 def main():
-    cli.main()
+    CliCreator.create()
 
 
 if __name__ == '__main__':
     main()
+
