@@ -1,5 +1,5 @@
 """
-Copyright (c) 2019-2020 Cypress Semiconductor Corporation
+Copyright (c) 2019-2021 Cypress Semiconductor Corporation
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -24,39 +24,50 @@ class CustomFormatter(logging.Formatter):
 
     def __init__(self):
         super().__init__(fmt="%(levelno)d: %(msg)s", datefmt=None, style='%')
+        self.style = self._style = CustomPercentStyle()
+        self.original_format = self.style.fmt
 
     def format(self, record):
-        # Save the original format
-        format_orig = self._style._fmt
-
-        # Replace the original format with custom
         if record.levelno == logging.DEBUG:
-            self._style._fmt = CustomFormatter.debug_fmt
+            self.style.fmt = CustomFormatter.debug_fmt
 
         elif record.levelno == logging.INFO:
-            self._style._fmt = CustomFormatter.info_fmt
+            self.style.fmt = CustomFormatter.info_fmt
 
         elif record.levelno == logging.WARNING:
-            self._style._fmt = CustomFormatter.warning_fmt
+            self.style.fmt = CustomFormatter.warning_fmt
 
         elif record.levelno == logging.ERROR:
-            self._style._fmt = CustomFormatter.error_fmt
+            self.style.fmt = CustomFormatter.error_fmt
 
         if record.name.startswith('pyocd'):
             package = 'P'
+        elif 'openocd' in record.name:
+            package = 'O'
         elif record.name.startswith('cysecuretools'):
             package = 'C'
             if record.levelno == logging.ERROR:
-                self._style._fmt += \
-                    '. Check the log for details'
+                self.style.fmt += '. Check the log for details'
         else:
             package = ' '
 
-        self._style._fmt = self._style._fmt.replace('##_package_##', package)
+        self.style.fmt = self.style.fmt.replace('##_package_##', package)
 
         result = logging.Formatter.format(self, record)
 
-        # Restore the original format
-        self._style._fmt = format_orig
+        self.style.fmt = self.original_format
 
         return result
+
+
+class CustomPercentStyle(logging.PercentStyle):
+    def __init__(self, fmt=None):
+        super().__init__(fmt)
+
+    @property
+    def fmt(self):
+        return self._fmt
+
+    @fmt.setter
+    def fmt(self, fmt):
+        self._fmt = fmt
